@@ -164,6 +164,8 @@ axis.default <-
 
     determineStatus <- function(x)
     {
+        ## whether the relevant component of 'components' wants us to
+        ## draw something here
         if (is.null(x) || (is.logical(x) && !x)) FALSE
         else TRUE
     }
@@ -182,28 +184,33 @@ axis.default <-
                right = column == layout.dim[2] || lastPanel())
     }
 
-    ## what about scales$relation ?
+    ## FIXME: what about scales$relation ?
     do.ticks <-
         switch(ticks,
                yes = TRUE,
                no = FALSE,
-               default = scales$draw && atBoundary() && determineStatus(components[[side]]))
+               default = scales$draw && determineStatus(components[[side]]) &&
+               (if (scales$relation == "same") atBoundary() else TRUE))
     do.labels <-
         switch(labels,
                yes = TRUE,
                no = FALSE,
 
                default =
-               scales$draw && atBoundary() &&
+               scales$draw &&
+               (if (scales$relation == "same") {
 
-               ## rule: if (alternating[row/column] %in% c(2, 3)) for
-               ## a ``boundary'' panel, then draw, otherwise don't.
-               switch(side,
-                      top    = rep(scales$alternating, length = column)[column] %in% c(2, 3),
-                      bottom = rep(scales$alternating, length = column)[column] %in% c(1, 3),
-                      left   = rep(scales$alternating, length = row)[row] %in% c(1, 3),
-                      right  = rep(scales$alternating, length = row)[row] %in% c(2, 3))
-               )
+                   atBoundary() &&
+
+                   ## rule: if (alternating[row/column] %in% c(2, 3)) for
+                   ## a ``boundary'' panel, then draw, otherwise don't.
+                   switch(side,
+                          top    = rep(scales$alternating, length = column)[column] %in% c(2, 3),
+                          bottom = rep(scales$alternating, length = column)[column] %in% c(1, 3),
+                          left   = rep(scales$alternating, length = row)[row] %in% c(1, 3),
+                          right  = rep(scales$alternating, length = row)[row] %in% c(2, 3))
+
+               } else TRUE)) 
 
     if (do.ticks || do.labels)
     {
@@ -277,7 +284,7 @@ calculateAxisComponents <-
 
     ## remove labels outside limits
     rng <- range(ans$num.limit)
-    ok <- ans$at >= rng[1] & ans$at <= rng[2]
+    ok <- ans$at >= min(rng) & ans$at <= max(rng)
     ans$at <- ans$at[ok]
     ans$labels <- ans$labels[ok]
 
@@ -414,7 +421,7 @@ formattedTicksAndLabels.character <-
               format.posixt, ...)
 {
     retain <- if (is.null(used.at) || any(is.na(used.at))) TRUE else used.at
-    ans <- list(at = if (is.logical(at)) seq(along = x)[retain] else at,
+    ans <- list(at = if (is.logical(at)) seq_along(x)[retain] else at,
                 labels = if (is.logical(labels)) x[retain] else labels,
                 check.overlap = FALSE)
     ans$num.limit <- c(-1, 1) * lattice.getOption("axis.padding")$factor + 
@@ -439,7 +446,7 @@ formattedTicksAndLabels.expression <-
              format.posixt, ...)
 {
     retain <- if (is.null(used.at) || any(is.na(used.at))) TRUE else used.at
-    ans <- list(at = if (is.logical(at)) seq(along = x)[retain] else at,
+    ans <- list(at = if (is.logical(at)) seq_along(x)[retain] else at,
                 labels = if (is.logical(labels)) x[retain] else labels,
                 check.overlap = FALSE)
     ans$num.limit <- c(-1, 1) * lattice.getOption("axis.padding")$factor + 
@@ -467,7 +474,7 @@ formattedTicksAndLabels.Date <-
         else range(as.numeric(x))
     mat <- is.logical(at)
     if(!mat) x <- as.Date(at) else x <- as.Date(x)
-    range <- range(num.lim)
+    range <- range(num.lim) # thus, range[1] <= range[2]
     range[1] <- ceiling(range[1])
     range[2] <- floor(range[2])
     ## find out the scale involved
@@ -702,7 +709,7 @@ panel.axis <-
 {
     side <- match.arg(side)
     orientation <- if (outside) "outer" else "inner"
-    cpl <- current.panel.limits() ## FIXME: grid should have accessors for xscale and yscale
+    cpl <- current.panel.limits()
     scale.range <-
         range(switch(side,
                      left = cpl$ylim,
@@ -753,7 +760,7 @@ panel.axis <-
     ## }
 
     nal <- length(at) / 2 + 0.5
-    all.id <- seq(along = at)
+    all.id <- seq_along(at)
     lower.id <- all.id <= nal
     upper.id <- all.id >= nal
     axid <-
